@@ -331,14 +331,25 @@ def predictDirectory(dirtag,modeltag):
             classify = getClassify(modeltag)
         else:
             return "error:model is not exists at [{}]".format(checkpoint_path)
-    
+    rtn = {
+        "dir":dirpath,
+        }
     imgs = os.listdir(dirpath)
     for img in imgs:
         imgpath = os.path.join(dirpath,img)
         result = predictSingle(imgpath,None,classify)
         print(result)
-    
-    
+        if "maybetype" in result:
+            maybetype = result["maybetype"]
+            if not maybetype in rtn:
+                rtn[maybetype] = 0
+            rtn[maybetype] += 1
+        else:
+            if "error" in result:
+                print("error occured stop predict directory process")
+                return
+    return rtn
+
 
 def predictSingle(imagepath,modeltag = None,classify = None):
     try:
@@ -353,10 +364,12 @@ def predictSingle(imagepath,modeltag = None,classify = None):
                 model.load_weights(checkpoint_path)
                 classify = getClassify(modeltag)
             else:
-                return "error:model is not exists at [{}]".format(checkpoint_path)
+                
+                raise Exception("model is not exists at [{}]".format(checkpoint_path))
         
         if not os.path.exists(imagepath):
-            return "error:picture is not exists at [{}]".format(imagepath)
+            
+            raise Exception("picture is not exists at [{}]".format(imagepath)")
         
         x = readBmp([imagepath],500,500,"bmp")
         
@@ -374,10 +387,15 @@ def predictSingle(imagepath,modeltag = None,classify = None):
         
         result = "name:{},maybe:{},percent:{}%,spend:{}s".format(imagename,maybetype,round(100.0*percent,2),round(e-s,2))
         #result = "maybe:{},{},{}".format(maybe,round(percent,2),round(e-s,2))
-        print(result)
+        result = {
+            "name":imagename,
+            "maybetype":maybetype,
+            "percent":round(percent,2),
+            "spend":round(e-s,2)
+            }
         return result
     except Exception as err:
-        return "error:{}".format(err)
+        return {"error":str(err)}
 
 def predictPicture(imagepath,ckptpath = None):
     try:
